@@ -1,9 +1,9 @@
-;;; guava-themes-solanum-theme.el --- A theme inspired by solanum colors -*- lexical-binding: t; -*-
+;;; guava-themes-solanum-theme.el --- A theme inspired by eggplant colors -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2025-2026
 
 ;; Author: Geralld Borbón <eternalmangocean@gmail.com>
-;; Created: Jan 12, 2026
+;; Created: Feb 22, 2026
 ;; Keywords: themes, faces, color
 ;; URL: http://github.com/bormoge/guava-themes
 ;; Package-Requires: ((emacs "24.1"))
@@ -138,7 +138,8 @@
    `(font-lock-variable-name-face ((,guava-themes-solanum-class (:foreground ,guava-themes-solanum-light-green :weight medium))))
 
    ;; parentheses
-   `(show-paren-match ((,guava-themes-solanum-class (:background ,guava-themes-solanum-light-blue))))
+   `(show-paren-match ((,guava-themes-solanum-class (:foreground ,guava-themes-solanum-purple-black :background ,guava-themes-solanum-light-blue))))
+   `(show-paren-mismatch ((,guava-themes-solanum-class (:foreground ,guava-themes-solanum-white :background ,guava-themes-solanum-error))))
 
    ;; buttons
    `(link ((,guava-themes-solanum-class (:foreground ,guava-themes-solanum-light-purple :underline t :weight bold))))
